@@ -8,13 +8,11 @@ from ..messages import *
 def processTags(doc):
     for el in findAll("[data-span-tag]", doc):
         if not constants.executeCode:
-            die(
-                "Found an inline code tag, but arbitrary code execution isn't allowed. See the --allow-execute flag."
-            )
+            die("Found an inline code tag, but arbitrary code execution isn't allowed. See the --allow-execute flag.")
             return
         tag = el.get("data-span-tag")
         if tag not in doc.md.inlineTagCommands:
-            die("Unknown inline tag '{0}' found:\n  {1}", tag, outerHTML(el), el=el)
+            die(f"Unknown inline tag '{tag}' found:\n  {outerHTML(el)}", el=el)
             continue
         command = doc.md.inlineTagCommands[tag]
         with Popen(command, stdin=PIPE, stdout=PIPE, stderr=PIPE, shell=True) as p:
@@ -22,27 +20,14 @@ def processTags(doc):
             try:
                 out = out.decode("utf-8")
             except UnicodeDecodeError as e:
-                die(
-                    "When trying to process {0}, got invalid unicode in stdout:\n{1}",
-                    outerHTML(el),
-                    e,
-                    el=el,
-                )
+                die(f"When trying to process {outerHTML(el)}, got invalid unicode in stdout:\n{e}", el=el)
             try:
                 err = err.decode("utf-8")
             except UnicodeDecodeError as e:
-                die(
-                    "When trying to process {0}, got invalid unicode in stderr:\n{1}",
-                    outerHTML(el),
-                    e,
-                    el=el,
-                )
+                die(f"When trying to process {outerHTML(el)}, got invalid unicode in stderr:\n{e}", el=el)
             if p.returncode:
                 die(
-                    "When trying to process {0}, got return code {1} and the following stderr:\n{2}",
-                    outerHTML(el),
-                    p.returncode,
-                    err,
+                    f"When trying to process {outerHTML(el)}, got return code {p.returncode} and the following stderr:\n{err}",
                     el=el,
                 )
                 continue
