@@ -197,7 +197,9 @@ class MetadataManager:
             return
 
         if self.status in ("w3c/IG-NOTE", "w3c/WG-NOTE"):
-            die(f"Under Process2021, {self.status} is no longer a valid status. Use NOTE (or one of its variants NOTE-ED, NOTE-FPWD, NOTE-WD) instead.")
+            die(
+                f"Under Process2021, {self.status} is no longer a valid status. Use NOTE (or one of its variants NOTE-ED, NOTE-FPWD, NOTE-WD) instead."
+            )
 
         # { MetadataManager attr : metadata name (for printing) }
         requiredSingularKeys = {
