@@ -27,10 +27,7 @@ def parse(string):
         if line.startswith(initialIndent):
             lines[i] = line[len(initialIndent) :]
         else:
-            die(
-                "Inconsistent indentation: line {0} is indented less than the first line.",
-                i,
-            )
+            die(f"Inconsistent indentation: line {i} is indented less than the first line.")
             return rr.Diagram()
 
     # Determine subsequent indentation
@@ -54,21 +51,13 @@ def parse(string):
             indent += 1
             line = line[len(indentText) :]
         if indent > lastIndent + 1:
-            die(
-                "Line {0} jumps more than 1 indent level from the previous line:\n{1}",
-                i,
-                line.strip(),
-            )
+            die(f"Line {i} jumps more than 1 indent level from the previous line:\n{line.strip()}")
             return rr.Diagram()
         lastIndent = indent
         if re.match(fr"\s*({blockNames})\W", line):
             match = re.match(r"\s*(\w+)\s*:\s*(.*)", line)
             if not match:
-                die(
-                    "Line {0} doesn't match the grammar 'Command: optional-prelude'. Got:\n{1}",
-                    i,
-                    line.strip(),
-                )
+                die(f"Line {i} doesn't match the grammar 'Command: optional-prelude'. Got:\n{line.strip()}")
                 return rr.Diagram()
             command = match.group(1)
             prelude = match.group(2).strip()
@@ -76,11 +65,7 @@ def parse(string):
         elif re.match(fr"\s*({textNames})\W", line):
             match = re.match(r"\s*(\w+)(\s[\w\s]+)?:\s*(.*)", line)
             if not match:
-                die(
-                    "Line {0} doesn't match the grammar 'Command [optional prelude]: text'. Got:\n{1},",
-                    i,
-                    line.strip(),
-                )
+                die(f"Line {i} doesn't match the grammar 'Command [optional prelude]: text'. Got:\n{line.strip()},")
                 return rr.Diagram()
             command = match.group(1)
             if match.group(2):
@@ -97,9 +82,7 @@ def parse(string):
             }
         else:
             die(
-                "Line {0} doesn't contain a valid railroad-diagram command. Got:\n{1}",
-                i,
-                line.strip(),
+                f"Line {i} doesn't contain a valid railroad-diagram command. Got:\n{line.strip()}",
             )
             return
 
@@ -120,34 +103,34 @@ def _createDiagram(command, prelude, children, text=None, line=-1):
         return rr.Diagram(*children)
     if command in ("T", "Terminal"):
         if children:
-            return die("Line {0} - Terminal commands cannot have children.", line)
+            return die(f"Line {line} - Terminal commands cannot have children.")
         return rr.Terminal(text, prelude)
     if command in ("N", "NonTerminal"):
         if children:
-            return die("Line {0} - NonTerminal commands cannot have children.", line)
+            return die(f"Line {line} - NonTerminal commands cannot have children.")
         return rr.NonTerminal(text, prelude)
     if command in ("C", "Comment"):
         if children:
-            return die("Line {0} - Comment commands cannot have children.", line)
+            return die(f"Line {line} - Comment commands cannot have children.")
         return rr.Comment(text, prelude)
     if command in ("S", "Skip"):
         if children:
-            return die("Line {0} - Skip commands cannot have children.", line)
+            return die(f"Line {line} - Skip commands cannot have children.")
         if text:
-            return die("Line {0} - Skip commands cannot have text.", line)
+            return die(f"Line {line} - Skip commands cannot have text.")
         return rr.Skip()
     if command in ("And", "Seq", "Sequence"):
         if prelude:
-            return die("Line {0} - Sequence commands cannot have preludes.", line)
+            return die(f"Line {line} - Sequence commands cannot have preludes.")
         if not children:
-            return die("Line {0} - Sequence commands need at least one child.", line)
+            return die(f"Line {line} - Sequence commands need at least one child.")
         children = [_f for _f in [_createDiagram(**child) for child in children] if _f]
         return rr.Sequence(*children)
     if command in ("Stack",):
         if prelude:
-            return die("Line {0} - Stack commands cannot have preludes.", line)
+            return die(f"Line {line} - Stack commands cannot have preludes.")
         if not children:
-            return die("Line {0} - Stack commands need at least one child.", line)
+            return die(f"Line {line} - Stack commands need at least one child.")
         children = [_f for _f in [_createDiagram(**child) for child in children] if _f]
         return rr.Stack(*children)
     if command in ("Or", "Choice"):
@@ -157,39 +140,31 @@ def _createDiagram(command, prelude, children, text=None, line=-1):
             try:
                 default = int(prelude)
             except ValueError:
-                die(
-                    "Line {0} - Choice preludes must be an integer. Got:\n{1}",
-                    line,
-                    prelude,
-                )
+                die(f"Line {line} - Choice preludes must be an integer. Got:\n{prelude}")
                 default = 0
         if not children:
-            return die("Line {0} - Choice commands need at least one child.", line)
+            return die(f"Line {line} - Choice commands need at least one child.")
         children = [_f for _f in [_createDiagram(**child) for child in children] if _f]
         return rr.Choice(default, *children)
     if command in ("Opt", "Optional"):
         if prelude not in ("", "skip"):
-            return die(
-                "Line {0} - Optional preludes must be nothing or 'skip'. Got:\n{1}",
-                line,
-                prelude,
-            )
+            return die(f"Line {line} - Optional preludes must be nothing or 'skip'. Got:\n{prelude}")
         if len(children) != 1:
-            return die("Line {0} - Optional commands need exactly one child.", line)
+            return die(f"Line {line} - Optional commands need exactly one child.")
         children = [_f for _f in [_createDiagram(**child) for child in children] if _f]
         return rr.Optional(*children, skip=(prelude == "skip"))
     if command in ("Plus", "OneOrMore"):
         if prelude:
-            return die("Line {0} - OneOrMore commands cannot have preludes.", line)
+            return die(f"Line {line} - OneOrMore commands cannot have preludes.")
         if 0 == len(children) > 2:
-            return die("Line {0} - OneOrMore commands must have one or two children.", line)
+            return die(f"Line {line} - OneOrMore commands must have one or two children.")
         children = [_f for _f in [_createDiagram(**child) for child in children] if _f]
         return rr.OneOrMore(*children)
     if command in ("Star", "ZeroOrMore"):
         if prelude:
-            return die("Line {0} - ZeroOrMore commands cannot have preludes.", line)
+            return die(f"Line {line} - ZeroOrMore commands cannot have preludes.")
         if 0 == len(children) > 2:
-            return die("Line {0} - ZeroOrMore commands must have one or two children.", line)
+            return die(f"Line {line} - ZeroOrMore commands must have one or two children.")
         children = [_f for _f in [_createDiagram(**child) for child in children] if _f]
         return rr.ZeroOrMore(*children)
-    return die("Line {0} - Unknown command '{1}'.", line, command)
+    return die(f"Line {line} - Unknown command '{command}'.")
