@@ -13,16 +13,13 @@ def update(path, dryRun=False):
     try:
         response = requests.get(specMapURL)
     except Exception as e:
-        die("Couldn't download the MDN Spec Links data.\n{0}", e)
+        die(f"Couldn't download the MDN Spec Links data.\n{e}")
         return
 
     try:
         data = response.json(encoding="utf-8", object_pairs_hook=OrderedDict)
     except Exception as e:
-        die(
-            "The MDN Spec Links data wasn't valid JSON for some reason." + " Try downloading again?\n{0}",
-            e,
-        )
+        die(f"The MDN Spec Links data wasn't valid JSON for some reason. Try downloading again?\n{e}")
         return
     writtenPaths = set()
     if not dryRun:
@@ -48,15 +45,12 @@ def update(path, dryRun=False):
                 try:
                     fileContents = requests.get(mdnSpecLinksBaseURL + specFilename).text
                 except Exception as e:
-                    die(
-                        "Couldn't download the MDN Spec Links " + specFilename + " file.\n{0}",
-                        e,
-                    )
+                    die(f"Couldn't download the MDN Spec Links {specFilename} file.\n{e}")
                     return
                 with open(p, "w", encoding="utf-8") as fh:
                     fh.write(fileContents)
         except Exception as e:
-            die("Couldn't save MDN Spec Links data to disk.\n{0}", e)
+            die(f"Couldn't save MDN Spec Links data to disk.\n{e}")
             return
     say("Success!")
     return writtenPaths
