@@ -10,6 +10,7 @@ from ..h import (
     parseHTML,
 )
 from ..messages import *
+from .. import config
 
 
 def processWptElements(doc):
@@ -29,11 +30,7 @@ def processWptElements(doc):
         testNames = testNamesFromEl(el, pathPrefix=pathPrefix)
         for testName in testNames:
             if testName not in testData:
-                die(
-                    "Couldn't find WPT test '{0}' - did you misspell something?",
-                    testName,
-                    el=el,
-                )
+                die(f"Couldn't find WPT test '{testName}' - did you misspell something?", el=el)
                 continue
             seenTestNames.add(testName)
         if el.get("hidden") is not None:
@@ -42,7 +39,6 @@ def processWptElements(doc):
             title = el.get("title")
             titleLang = el.get("lang")
             titleDir = el.get("dir")
-            createHTML(doc, el, testNames, testData, title, titleLang, titleDir)
             if prevEl is not None and prevEl.getnext() is el and (prevEl.tail is None or prevEl.tail.strip() == ""):
                 appendTestList(prevEl, testNames, testData, title, titleLang, titleDir)
                 removeNode(el)
@@ -55,10 +51,7 @@ def processWptElements(doc):
     if wptRestElements and testData is None:
         testData = loadTestData(doc)
     if len(wptRestElements) > 1:
-        die(
-            "Only one <wpt-rest> element allowed per document, you have {0}.",
-            len(wptRestElements),
-        )
+        die(f"Only one <wpt-rest> element allowed per document, you have {len(wptRestElements)}.")
         wptRestElements = wptRestElements[0:1]
     elif len(wptRestElements) == 1:
         localPrefix = wptRestElements[0].get("pathprefix")
@@ -70,7 +63,7 @@ def processWptElements(doc):
         atLeastOneElement = True
         prefixedNames = [p for p in testData if prefixInPath(pathPrefix, p) and p not in seenTestNames]
         if len(prefixedNames) == 0:
-            die("Couldn't find any tests with the path prefix '{0}'.", pathPrefix)
+            die(f"Couldn't find any tests with the path prefix '{pathPrefix}'.")
             return
         createHTML(doc, wptRestElements[0], prefixedNames, testData)
         warn(
@@ -82,8 +75,25 @@ def processWptElements(doc):
                 testData = loadTestData(doc)
             checkForOmittedTests(pathPrefix, testData, seenTestNames)
 
+    if seenTestNames:
+        if pathPrefix is None:
+            pathPrefix = commonPathPrefix(seenTestNames)
+        if not pathPrefix.startswith("/"):
+            pathPrefix = "/" + pathPrefix
+        if pathPrefix != "/":
+            doc.md.otherMetadata["Test Suite"].append(
+                E.dd(
+                    {"class": "wpt-overview"},
+                    E.a(
+                        {"href": f"https://wpt.fyi/results{pathPrefix}"},
+                        f"https://wpt.fyi/results{pathPrefix}",
+                    ),
+                )
+            )
+
     if atLeastOneElement and doc.md.wptDisplay != "none":
         doc.extraStyles["style-wpt"] = wptStyle
+        doc.extraScripts["script-wpt"] = getWptScript(pathPrefix)
 
 
 def createHTML(doc, blockEl, testNames, testData, title=None, titleLang=None, titleDir=None):
@@ -133,6 +143,7 @@ def appendTestList(blockEl, testNames, testData, title=None, titleLang=None, tit
                 {"class": "wpt-test"},
                 E.a(
                     {
+                        "title": testName,
                         "href": "https://wpt.fyi/results/" + testName,
                         "class": "wpt-name",
                     },
@@ -141,7 +152,6 @@ def appendTestList(blockEl, testNames, testData, title=None, titleLang=None, tit
                 " ",
                 E.a(
                     {
-                        "title": testName,
                         "href": f"{liveTestScheme}://wpt.live/{testName}",
                         "class": "wpt-live",
                     },
@@ -249,10 +259,8 @@ def checkForOmittedTests(pathPrefix, testData, seenTestNames):
         numTests = len(unseenTests)
         if numTests < 10:
             warn(
-                "There are {} WPT tests underneath your path prefix '{}' that aren't in your document and must be added:\n{}",
-                numTests,
-                pathPrefix,
-                "\n".join("  " + path for path in sorted(unseenTests)),
+                f"There are {numTests} WPT tests underneath your path prefix '{pathPrefix}' that aren't in your document and must be added:\n"
+                + "\n".join("  " + path for path in sorted(unseenTests)),
             )
         else:
             warn(
@@ -272,6 +280,23 @@ def xor(a, b):
     return bool(a) != bool(b)
 
 
+def commonPathPrefix(paths):
+    paths = [x.split("/")[:-1] for x in paths]
+    commonPrefix = paths[0]
+    for path in paths[1:]:
+        # can't have a common prefix longer than the shortest path
+        if len(path) < len(commonPrefix):
+            commonPrefix = commonPrefix[: len(path)]
+        # now compare the remaining segments
+        for i in range(0, min(len(commonPrefix), len(path))):
+            if path[i] != commonPrefix[i]:
+                commonPrefix = commonPrefix[:i]
+                break
+    if len(commonPrefix) >= 1:
+        return "/" + "/".join(commonPrefix) + "/"
+    return None
+
+
 wptStyle = """
 :root {
     --wpt-border: hsl(0, 0%, 60%);
@@ -379,7 +404,7 @@ dd:not(:last-child) > .wpt-tests-block:not([open]):last-child {
     display: grid;
     margin: 0;
     padding: 0;
-    grid-template-columns: 1fr auto auto;
+    grid-template-columns: 1fr max-content auto auto;
     grid-column-gap: .5em;
 }
 .wpt-tests-block hr:last-child {
@@ -393,6 +418,32 @@ dd:not(:last-child) > .wpt-tests-block:not([open]):last-child {
     border: none;
 }
 .wpt-test > .wpt-name { grid-column: 1; }
-.wpt-test > .wpt-live { grid-column: 2; }
-.wpt-test > .wpt-source { grid-column: 3; }
+.wpt-test > .wpt-results { grid-column: 2; }
+.wpt-test > .wpt-live { grid-column: 3; }
+.wpt-test > .wpt-source { grid-column: 4; }
+
+.wpt-test > .wpt-results {
+    display: flex;
+    gap: .1em;
+}
+.wpt-test .wpt-result {
+    display: inline-block;
+    height: 1em;
+    width: 1em;
+    border-radius: 50%;
+    position: relative;
+}
 """
+
+
+def getWptScript(path):
+    if path is None:
+        path = "/"
+    if not path.startswith("/"):
+        path = "/" + path
+    if not path.endswith("/"):
+        path = path + "/"
+    script = f'let wptPath = "{path}";\n'
+    with open(config.scriptPath("wpt", "wptScript.js"), "r", encoding="utf-8") as fh:
+        script += fh.read()
+    return script
